window.onload = function() {
    var map = L.map('map').setView([12.3711, -1.5197], 13);
    var destinationMarker; // Marqueur pour la destination
    var sourceMarker; // Marqueur pour le point de départ

    L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
        attribution: '© OpenStreetMap contributors',
        minZoom: 1,
        maxZoom: 20
    }).addTo(map);

    var control = L.Routing.control({
        lineOptions: {
            styles: [{ color: '#839c49', opacity: 1, weight: 7 }]
        },
        router: new L.Routing.osrmv1({
            language: 'fr',
            profile: 'car'
        }),
        waypoints: [],
        createMarker: function(i, waypoint, n) {
            var marker = L.marker(waypoint.latLng, { draggable: true })
                .bindPopup(i === 0 ? "Point de départ" : "Point d'arrivée")
                .on('dragend', function(e) {
                    var newLatLng = e.target.getLatLng();
                    control.spliceWaypoints(i, 1, newLatLng);
                    updateMarkers(); // Met à jour les marqueurs sur la carte
                });
            return marker;
        },
        routeWhileDragging: true,
        show: false,
        draggableWaypoints: true
    }).addTo(map);

    function updateMarkers() {
        // Met à jour les marqueurs pour qu'ils soient alignés avec les waypoints
        if (sourceMarker) {
            var sourceLatLng = control.getWaypoints()[0].latLng;
            sourceMarker.setLatLng(sourceLatLng);
        }
        if (destinationMarker) {
            var destinationLatLng = control.getWaypoints()[1].latLng;
            destinationMarker.setLatLng(destinationLatLng);
        }
    }

    // Fonction pour afficher les suggestions d'adresse (autocomplétion)
    function afficherSuggestions(input, containerSuggestions, inputElement) {
        if (input.length < 2) {
            containerSuggestions.innerHTML = ''; // Effacer les suggestions si l'entrée est trop courte
            return;
        }

        var url = `https://nominatim.openstreetmap.org/search?format=json&q=${encodeURIComponent(input)}&countrycodes=BF&accept-language=fr&addressdetails=1&limit=50`;

        fetch(url)
            .then(response => response.json())
            .then(data => {
                containerSuggestions.innerHTML = ''; // Effacer les suggestions précédentes
                if (data.length > 0) {
                    data.forEach(result => {
                        var suggestion = document.createElement('div');
                        suggestion.className = 'suggestion';
                        suggestion.textContent = result.display_name;
                        suggestion.onclick = function() {
                            inputElement.value = result.display_name;
                            var destinationLatLng = [result.lat, result.lon];

                            // Ajouter ou mettre à jour le marqueur
                            if (inputElement === document.getElementById('source-search')) {
                                if (sourceMarker) {
                                    map.removeLayer(sourceMarker);
                                }
                                sourceMarker = L.marker(destinationLatLng, { draggable: true })
                                    .addTo(map)
                                    .bindPopup("Point de départ")
                                    .openPopup()
                                    .on('dragend', function(e) {
                                        var newLatLng = e.target.getLatLng();
                                        control.spliceWaypoints(0, 1, newLatLng);
                                        updateMarkers(); // Met à jour les marqueurs sur la carte
                                    });
                            } else {
                                if (destinationMarker) {
                                    map.removeLayer(destinationMarker);
                                }
                                destinationMarker = L.marker(destinationLatLng, { draggable: true })
                                    .addTo(map)
                                    .bindPopup("Point d'arrivée")
                                    .openPopup()
                                    .on('dragend', function(e) {
                                        var newLatLng = e.target.getLatLng();
                                        control.spliceWaypoints(1, 1, newLatLng);
                                        updateMarkers(); // Met à jour les marqueurs sur la carte
                                    });
                            }
                            containerSuggestions.innerHTML = ''; // Effacer les suggestions après la sélection
                        };
                        containerSuggestions.appendChild(suggestion);
                    });
                }
            })
            .catch(error => {
                console.error("Erreur lors de la récupération des suggestions : ", error);
            });
    }

    // Écouteurs pour les champs de recherche
    document.getElementById('source-search').addEventListener('input', function() {
        var input = this.value;
        var containerSuggestions = document.getElementById('source-suggestions');
        afficherSuggestions(input, containerSuggestions, this);
    });

    document.getElementById('destination-search').addEventListener('input', function() {
        var input = this.value;
        var containerSuggestions = document.getElementById('destination-suggestions');
        afficherSuggestions(input, containerSuggestions, this);
    });

    // Autres fonctions inchangées ...


    document.getElementById('set-destinations-btn').onclick = function() {
        var sourceQuery = document.getElementById('source-search').value;
        var destinationQuery = document.getElementById('destination-search').value;

        if (sourceQuery && destinationQuery) {
            fetch(`https://nominatim.openstreetmap.org/search?format=json&q=${encodeURIComponent(sourceQuery)}&countrycodes=BF`)
                .then(response => response.json())
                .then(data => {
                    if (data.length > 0) {
                        var sourceLatLng = [data[0].lat, data[0].lon];
                        fetch(`https://nominatim.openstreetmap.org/search?format=json&q=${encodeURIComponent(destinationQuery)}&countrycodes=BF`)
                            .then(response => response.json())
                            .then(data => {
                                if (data.length > 0) {
                                    var destinationLatLng = [data[0].lat, data[0].lon];
                                    control.setWaypoints([sourceLatLng, destinationLatLng]);
                                    
                                    // Ajouter les marqueurs
                                    if (sourceMarker) {
                                        map.removeLayer(sourceMarker);
                                    }
                                    sourceMarker = L.marker(sourceLatLng, { draggable: true })
                                        .addTo(map)
                                        .bindPopup("Point de départ")
                                        .on('dragend', function(e) {
                                            var newLatLng = e.target.getLatLng();
                                            control.spliceWaypoints(0, 1, newLatLng);
                                            updateMarkers(); // Met à jour les marqueurs sur la carte
                                        });

                                    if (destinationMarker) {
                                        map.removeLayer(destinationMarker);
                                    }
                                    destinationMarker = L.marker(destinationLatLng, { draggable: true })
                                        .addTo(map)
                                        .bindPopup("Point d'arrivée")
                                        .on('dragend', function(e) {
                                            var newLatLng = e.target.getLatLng();
                                            control.spliceWaypoints(1, 1, newLatLng);
                                            updateMarkers(); // Met à jour les marqueurs sur la carte
                                        });

                                    map.setView(sourceLatLng, 13);
                                    afficherInstructionsItineraire(control);
                                    document.getElementById('instructions-container').style.display = 'block';
                                } else {
                                    alert("Destination d'arrivée non trouvée, veuillez entrer une destination correcte.");
                                }
                            });
                    } else {
                        alert("Destination de départ non trouvée, veuillez entrer une destination correcte.");
                    }
                });
        } else {
            alert('Veuillez entrer à la fois une destination de départ et une destination d\'arrivée.');
        }
    };

    function afficherInstructionsItineraire(routingControl) {
        routingControl.on('routesfound', function(e) {
            var routes = e.routes;
            var listeInstructions = document.getElementById('instructions-list');
            listeInstructions.innerHTML = '';

            var distanceTotale = routes[0].summary.totalDistance;
            var tempsTotal = routes[0].summary.totalTime;

            var elementDistanceTotale = document.createElement('p');
            elementDistanceTotale.textContent = "Distance totale : " + (distanceTotale / 1000).toFixed(2) + " km";
            listeInstructions.appendChild(elementDistanceTotale);

            var tempsTotalMinutes = Math.ceil(tempsTotal / 60);
            var elementTempsTotal = document.createElement('p');
            elementTempsTotal.textContent = "Temps total : " + tempsTotalMinutes + " min";
            listeInstructions.appendChild(elementTempsTotal);

            routes[0].instructions.forEach(function(instruction) {
                var instructionTemps = instruction.time;
                var instructionTempsMinutes = Math.ceil(instructionTemps / 60);
                var elementListe = document.createElement('li');
                elementListe.textContent = instruction.text + " (" + instruction.distance.toFixed(0) + "m, " + instructionTempsMinutes + " min)";
                listeInstructions.appendChild(elementListe);
            });
        });
    }
};
